@@ -29,7 +29,7 @@ On a Debian/Ubuntu system you can install these modules using apt:
     sys.exit(1)
 
 from qtpy import QtWidgets
-from qtpy.QtCore import Qt
+from qtpy.QtCore import Qt, Signal
 
 try:
     # Qt 5.12 / PyQt 5.13 is unable to use QtWebEngineWidgets unless it is
@@ -49,6 +49,7 @@ from .widgets import standard
 from .widgets import startup
 from .settings import Session
 from .settings import Settings
+from . import cmd
 from . import cmds
 from . import core
 from . import compat
@@ -280,7 +281,7 @@ class ColaQApplication(QtWidgets.QApplication):
         view.save_state(settings=session)
 
 
-def process_args(args):
+def process_args(args, setup_repo=False):
     """Process and verify command-line arguments"""
     if args.version:
         # Accept 'git cola --version' or 'git cola version'
@@ -290,6 +291,15 @@ def process_args(args):
     # Handle session management
     restore_session(args)
 
+    # Initialize args.repo. If a repository was specified as a
+    # positional argument then we will use that value.
+    # If unspecified, the current directory is used.
+    if setup_repo and not args.repo:
+        if args.args and git.is_git_repository(args.args[0]):
+            args.repo = args.args.pop(0)
+    if not args.repo:
+        args.repo = core.getcwd()
+
     # Bail out if --repo is not a directory
     repo = core.decode(args.repo)
     if repo.startswith('file:'):
@@ -319,20 +329,27 @@ def restore_session(args):
         args.repo = session.repo
 
 
-def application_init(args, update=False, app_name='Git Cola'):
+def application_init(
+    args,
+    update=False,
+    app_name='Git Cola',
+    setup_worktree=True,
+    setup_repo=False,
+):
     """Parses the command-line arguments and starts git-cola"""
     # Ensure that we're working in a valid git repository.
     # If not, try to find one.  When found, chdir there.
     setup_environment()
-    process_args(args)
+    process_args(args, setup_repo=setup_repo)
 
     context = new_context(args, app_name=app_name)
     timer = context.timer
     timer.start('init')
 
-    new_worktree(context, args.repo, args.prompt)
-    if update:
-        context.model.update_status()
+    if setup_worktree:
+        new_worktree(context, args.repo, args.prompt)
+        if update:
+            context.model.update_status()
 
     timer.stop('init')
     if args.perf:
@@ -343,6 +360,7 @@ def application_init(args, update=False, app_name='Git Cola'):
 def new_context(args, app_name='Git Cola'):
     """Create top-level ApplicationContext objects"""
     context = ApplicationContext(args)
+    context.timestamp = time.time()
     context.settings = args.settings or Settings.read()
     context.git = git.create()
     context.cfg = gitcfg.create(context)
@@ -415,7 +433,6 @@ def add_common_arguments(parser):
         '-r',
         '--repo',
         metavar='<repo>',
-        default=core.getcwd(),
         help='open the specified git repository',
     )
 
@@ -612,9 +629,11 @@ class ApplicationContext:
     def __init__(self, args):
         self.args = args
         self.app = None  # ColaApplication
+        self.command_bus = None  # cmd.CommandBus
         self.git = None  # git.Git
         self.cfg = None  # gitcfg.GitConfig
         self.model = None  # main.MainModel
+        self.notifier = Notifier(self)
         self.timer = None  # Timer
         self.runtask = None  # qtutils.RunTask
         self.settings = None  # settings.Settings
@@ -626,7 +645,48 @@ class ApplicationContext:
     def set_view(self, view):
         """Initialize view-specific members"""
         self.view = view
+        self.notifier.setParent(view)
+        self.command_bus = cmd.CommandBus(parent=view)
         self.runtask = qtutils.RunTask(parent=view)
+        self.notifier.critical.connect(self._critical, Qt.QueuedConnection)
+        self.notifier.information.connect(self._information, Qt.QueuedConnection)
+        self.notifier.log.connect(self._log, Qt.QueuedConnection)
+
+    def _critical(self, title, kwargs):
+        Interaction.critical(title, **kwargs)
+
+    def _information(self, title, kwargs):
+        Interaction.information(title, **kwargs)
+
+    def _log(self, message):
+        Interaction.log(message)
+
+
+class Notifier(QtCore.QObject):
+    """Message bus for generic one-off notifications"""
+
+    critical = Signal(object, object)
+    information = Signal(object, object)
+    log = Signal(object)
+    message = Signal(object)
+
+    def __init__(self, context, parent=None):
+        super().__init__(parent)
+        self.context = context
+
+    def notify(self, message):
+        """Send messages to listeners"""
+        self.message.emit(message)
+
+    def listen(self, message, callback):
+        """Subscribe a callback specific messages"""
+
+        def listener(current_message, message=message, callback=callback):
+            """Fire a callback when specific messages are seen"""
+            if current_message is message:
+                callback()
+
+        self.message.connect(listener, type=Qt.QueuedConnection)
 
 
 def find_git():
