@@ -10,6 +10,7 @@ def hotkey(*seq):
 
 # A-G
 STAGE_MODIFIED = hotkey(Qt.ALT | Qt.Key_A)
+STASH_ALL = hotkey(Qt.ALT | Qt.Key_A)
 WORD_LEFT = hotkey(Qt.Key_B)
 BLAME = hotkey(Qt.CTRL | Qt.SHIFT | Qt.Key_B)
 BRANCH = hotkey(Qt.CTRL | Qt.Key_B)
@@ -17,6 +18,9 @@ CHECKOUT = hotkey(Qt.ALT | Qt.Key_B)
 CHERRY_PICK = hotkey(Qt.CTRL | Qt.SHIFT | Qt.Key_C)
 COPY_COMMIT_ID = hotkey(Qt.CTRL | Qt.ALT | Qt.Key_C)
 COPY_DIFF = hotkey(Qt.ALT | Qt.SHIFT | Qt.Key_C)
+CTRL_1 = hotkey(Qt.CTRL | Qt.Key_1)
+CTRL_2 = hotkey(Qt.CTRL | Qt.Key_2)
+CTRL_3 = hotkey(Qt.CTRL | Qt.Key_3)
 DIFFSTAT = hotkey(Qt.ALT | Qt.Key_D)
 DIFF = hotkey(Qt.CTRL | Qt.Key_D)
 DIFF_SECONDARY = hotkey(Qt.CTRL | Qt.SHIFT | Qt.Key_D)
@@ -68,6 +72,7 @@ REFRESH_SECONDARY = hotkey(Qt.Key_F5)
 REFRESH_HOTKEYS = (REFRESH, REFRESH_SECONDARY)
 STAGE_DIFF = hotkey(Qt.Key_S)
 EDIT_AND_STAGE_DIFF = hotkey(Qt.CTRL | Qt.SHIFT | Qt.Key_S)
+SAVE = hotkey(Qt.CTRL | Qt.Key_S)
 SEARCH = hotkey(Qt.CTRL | Qt.Key_F)
 SEARCH_NEXT = hotkey(Qt.CTRL | Qt.Key_G)
 SEARCH_PREV = hotkey(Qt.CTRL | Qt.SHIFT | Qt.Key_G)
@@ -75,12 +80,15 @@ STAGE_DIFF_ALT = hotkey(Qt.SHIFT | Qt.Key_S)
 STAGE_SELECTION = hotkey(Qt.CTRL | Qt.Key_S)
 STAGE_ALL = hotkey(Qt.CTRL | Qt.SHIFT | Qt.Key_S)
 STASH = hotkey(Qt.ALT | Qt.SHIFT | Qt.Key_S)
+STASH_STAGED = hotkey(Qt.ALT | Qt.Key_S)
 FINDER = hotkey(Qt.CTRL | Qt.Key_T)
 FINDER_SECONDARY = hotkey(Qt.Key_T)
 TERMINAL = hotkey(Qt.CTRL | Qt.SHIFT | Qt.Key_T)
 STAGE_UNTRACKED = hotkey(Qt.ALT | Qt.Key_U)
+STASH_UNSTAGED = hotkey(Qt.ALT | Qt.Key_U)
 REVERT = hotkey(Qt.CTRL | Qt.Key_U)
 REVERT_ALT = hotkey(Qt.ALT | Qt.SHIFT | Qt.Key_R)
+REVERT_UNSTAGED_EDITS = hotkey(Qt.ALT | Qt.CTRL | Qt.Key_U)
 EDIT_AND_REVERT = hotkey(Qt.CTRL | Qt.SHIFT | Qt.Key_U)
 WORD_RIGHT = hotkey(Qt.Key_W)
 
