@@ -5,6 +5,7 @@ from qtpy import QtCore
 from qtpy.QtCore import Signal
 
 from .. import core
+from .. import git
 from .. import gitcmds
 from .. import gitcfg
 from .. import version
@@ -98,6 +99,7 @@ class MainModel(QtCore.QObject):
         self.is_merging = False
         self.is_rebasing = False
         self.is_applying_patch = False
+        self.commit_author = None
         self.currentbranch = ''
         self.directory = ''
         self.project = ''
@@ -108,6 +110,10 @@ class MainModel(QtCore.QObject):
         self.commitmsg = ''  # current commit message
         self._auto_commitmsg = ''  # e.g. .git/MERGE_MSG
         self._prev_commitmsg = ''  # saved here when clobbered by .git/MERGE_MSG
+        self.object_format = 'sha1'  # repository object format variables.
+        self.oid_len = git.OID_LENGTH_SHA1
+        self.empty_tree_oid = git.EMPTY_TREE_SHA1
+        self.missing_blob_oid = git.MISSING_BLOB_SHA1
 
         self.modified = []  # modified, staged, untracked, unmerged paths
         self.staged = []
@@ -208,6 +214,10 @@ class MainModel(QtCore.QObject):
         if notify:
             self.commit_message_changed.emit(msg)
 
+    def set_commit_author(self, author):
+        """Set the author that will be used when creating commits"""
+        self.commit_author = author
+
     def save_commitmsg(self, msg=None):
         if msg is None:
             msg = self.commitmsg
@@ -320,6 +330,16 @@ class MainModel(QtCore.QObject):
             self.cfg.reset()
         self.annex = self.cfg.is_annex()
         self.lfs = self.is_git_lfs_enabled()
+        # Update sha256 / sha1 repository state.
+        self.object_format = self.cfg.get_object_format()
+        if self.object_format == 'sha256':
+            self.oid_len = git.OID_LENGTH_SHA256
+            self.empty_tree_oid = git.EMPTY_TREE_SHA256
+            self.missing_blob_oid = git.MISSING_BLOB_SHA256
+        else:
+            self.oid_len = git.OID_LENGTH_SHA1
+            self.empty_tree_oid = git.EMPTY_TREE_SHA1
+            self.missing_blob_oid = git.MISSING_BLOB_SHA1
         if emit:
             self.emit_updated()
 
@@ -364,7 +384,7 @@ class MainModel(QtCore.QObject):
         return not self.local_branches
 
     def _update_remotes(self):
-        self.remotes = gitcfg.get_remotes(self.cfg)
+        self.remotes = sorted(gitcfg.get_remotes(self.cfg))
 
     def _update_branches_and_tags(self):
         context = self.context
