@@ -27,6 +27,7 @@ DIFFTOOL = 'diff.tool'
 DISPLAY_UNTRACKED = 'gui.displayuntracked'
 EDITOR = 'gui.editor'
 ENABLE_GRAVATAR = 'cola.gravatar'
+ENABLE_POPUPS = 'cola.enablepopups'
 EXPANDTAB = 'cola.expandtab'
 FONTDIFF = 'cola.fontdiff'
 FONTSIZE = 'cola.fontsize'
@@ -46,6 +47,7 @@ MERGE_VERBOSITY = 'merge.verbosity'
 MERGETOOL = 'merge.tool'
 MOUSE_ZOOM = 'cola.mousezoom'
 PATCHES_DIRECTORY = 'cola.patchesdirectory'
+PULL_REBASE = 'pull.rebase'
 REBASE_UPDATE_REFS = 'rebase.updaterefs'
 REFRESH_ON_FOCUS = 'cola.refreshonfocus'
 RESIZE_BROWSER_COLUMNS = 'cola.resizebrowsercolumns'
@@ -75,6 +77,17 @@ class DateFormat:
     RAW = 'raw'
     HUMAN = 'human'
     UNIX = 'unix'
+    FORMAT = 'format:'
+
+    @classmethod
+    def is_custom(cls, value):
+        """Is the log format a custom log format?"""
+        return value.startswith(cls.FORMAT)
+
+    @classmethod
+    def get_custom_format(cls, value):
+        """Return the custom format in a format:<...> string"""
+        return value[len(cls.FORMAT) :]
 
 
 def date_formats():
@@ -125,6 +138,7 @@ class Defaults:
     difftool = 'xxdiff'
     editor = 'gvim'
     enable_gravatar = True
+    enable_popups = False
     expandtab = False
     history_browser = 'gitk'
     http_proxy = ''
@@ -228,6 +242,11 @@ def background_editor(context):
     return _remap_editor(app)
 
 
+def enable_popups(context):
+    """Should popups be used instead of notifications/logs?"""
+    return context.cfg.get(ENABLE_POPUPS, default=Defaults.enable_popups)
+
+
 def fallback_editor():
     """Return a fallback editor for cases where one is not configured
 
