@@ -81,7 +81,7 @@ def command(name):
 
 
 def doc(*args):
-    """Return a path relative to cola's /usr/share/doc/ directory or the docs/ directory"""
+    """Return a path relative to cola's /usr/share/doc/ or the docs/ directory"""
     # pyproject.toml does not support data_files in pyproject.toml so we install the
     # hotkey files as cola/data/ package data. This is a fallback location for when
     # users did not use the garden.yaml or Makefile to install cola.
