@@ -161,7 +161,7 @@ class Editor(QtWidgets.QWidget):
         self.filename = filename
         self.comment_char = comment_char = prefs.comment_char(context)
 
-        self.diff = diff.DiffWidget(context, self)
+        self.diff = diff.CommitDiffWidget(context, self)
         self.tree = RebaseTreeWidget(context, comment_char, self)
         self.filewidget = filelist.FileWidget(context, self, remarks=True)
         self.setFocusProxy(self.tree)
@@ -272,9 +272,9 @@ class Editor(QtWidgets.QWidget):
         if not items:
             return
         item = items[0]
-        difftool.diff_expression(self.context, self, item.oid + '^!', hide_expr=True)
-
-    # helpers
+        difftool.diff_expression(
+            self.context, self, f'{item.oid}~..{item.oid}', hide_expr=True
+        )
 
     def paths_touched_by_oid(self, oid):
         try:
@@ -302,13 +302,12 @@ class Editor(QtWidgets.QWidget):
         update_ref_rgx = re.compile(
             r'^\s*(%s)?\s*(u|update-ref)\s+(.+)$' % re_comment_char
         )
-        # The upper bound of 40 below must match git.OID_LENGTH.
-        # We'll have to update this to the new hash length when that happens.
+        # The upper bound of 64 below must be >= all git.OID_LENGTH_XXX values.
         pick_rgx = re.compile(
             (
                 r'^\s*(%s)?\s*'
                 + r'(d|drop|e|edit|f|fixup|p|pick|r|reword|s|squash)'
-                + r'\s+([0-9a-f]{7,40})'
+                + r'\s+([0-9a-f]{7,64})'
                 + r'\s+(.+)$'
             )
             % re_comment_char
