@@ -34,6 +34,7 @@ from . import defs
 from . import diff
 from . import filelist
 from . import standard
+from . import finder
 
 
 def git_dag(context, args=None, existing_view=None, show=True):
@@ -118,6 +119,20 @@ class ViewerMixin:
             oid = None
         return oid
 
+    def clicked_commit(self, filtered=True):
+        """Return the clicked or selected commit object"""
+        if self.clicked:
+            item = self.clicked
+        else:
+            item = self.selected_item()
+        if item and hasattr(item, 'commit'):
+            commit = item.commit
+        else:
+            commit = item
+        if filtered and commit and commit.oid in (dag.STAGE, dag.WORKTREE):
+            commit = None
+        return commit
+
     def with_oid(self, func, filtered=True):
         """Run an operation with a commit object ID"""
         oid = self.clicked_oid(filtered=filtered)
@@ -207,18 +222,27 @@ class ViewerMixin:
 
     def show_diff(self):
         """Show the diff for the selected commit"""
+        commit = self.clicked_commit()
+        if not commit:
+            return
+        is_root_commit = not commit.parents
         self.with_oid(
-            lambda oid: _diff_expression(self.context, self, oid), filtered=False
+            lambda oid: _diff_expression(self.context, self, oid, is_root_commit),
+            filtered=False,
         )
 
     def show_dir_diff(self):
         """Show a full directory diff for the selected commit"""
         context = self.context
+        commit = self.clicked_commit()
+        if not commit:
+            return
+        is_root_commit = not commit.parents
         self.with_oid(
             lambda oid: difftool.difftool_launch(
                 context,
-                left=oid,
-                left_take_magic=True,
+                oid=oid,
+                is_root_commit=is_root_commit,
                 dir_diff=True,
                 staged=oid == dag.STAGE,
             ),
@@ -278,6 +302,10 @@ class ViewerMixin:
             lambda oid: _save_blob_from_parent(self.context, oid), filtered=False
         )
 
+    def search_line_range(self):
+        """Open a dialog to select a range of lines from a file"""
+        self.with_oid(lambda oid: self.search_line_range_in_oid.emit(oid))
+
     def update_menu_actions(self, event):
         """Update menu actions to reflect the selection state"""
         selected_items = self.selected_items()
@@ -366,6 +394,9 @@ class ViewerMixin:
         self.menu_actions['save_blob_from_parent'].setEnabled(
             has_single_selection_or_clicked
         )
+        self.menu_actions['search_line_range'].setEnabled(
+            has_single_selection_or_clicked and has_oid
+        )
 
     def context_menu_event(self, event):
         """Build a context menu and execute it"""
@@ -376,6 +407,8 @@ class ViewerMixin:
         menu.addAction(self.menu_actions['diff_commit'])
         menu.addAction(self.menu_actions['diff_commit_all'])
         menu.addSeparator()
+        menu.addAction(self.menu_actions['search_line_range'])
+        menu.addSeparator()
         menu.addAction(self.menu_actions['checkout_branch'])
         menu.addAction(self.menu_actions['create_branch'])
         menu.addAction(self.menu_actions['create_tag'])
@@ -403,14 +436,16 @@ class ViewerMixin:
         menu.exec_(self.mapToGlobal(event.pos()))
 
 
-def _diff_expression(context, widget, oid):
+def _diff_expression(context, widget, oid, is_root_commit):
     """Launch difftool using the specified object ID"""
     if oid == dag.WORKTREE:
         ref = ''
     elif oid == dag.STAGE:
         ref = '--cached'
+    elif is_root_commit:
+        ref = f'{context.model.empty_tree_oid}..{oid}'
     else:
-        ref = f'{oid}^!'
+        ref = f'{oid}~..{oid}'
     return difftool.diff_expression(
         context, widget, ref, hide_expr=False, focus_tree=True
     )
@@ -549,6 +584,14 @@ def viewer_actions(widget, proxy):
                 proxy.save_blob_from_parent_dialog,
             ),
         ),
+        'search_line_range': set_icon(
+            icons.search(),
+            qtutils.add_action(
+                widget,
+                N_('Trace Evolution of Line Range...'),
+                proxy.search_line_range,
+            ),
+        ),
         'copy': set_icon(
             icons.copy(),
             qtutils.add_action(
@@ -589,6 +632,9 @@ class GitDagLineEdit(completion.GitLogLineEdit):
         self._action_no_merges = qtutils.add_action(
             self, N_('Ignore merge commits'), self._no_merges
         )
+        self._action_filter_lines = qtutils.add_action(
+            self, N_('Filter commits by line range'), self._filter_to_line_range
+        )
 
     def contextMenuEvent(self, event):
         """Adds custom actions to the default context menu"""
@@ -598,6 +644,7 @@ class GitDagLineEdit(completion.GitLogLineEdit):
         actions = menu.actions()
         first_action = actions[0]
         menu.insertAction(first_action, self._action_pickaxe_search)
+        menu.insertAction(first_action, self._action_filter_lines)
         menu.insertAction(first_action, self._action_filter_to_current_author)
         menu.insertAction(first_action, self._action_grep_search)
         menu.insertAction(first_action, self._action_no_merges)
@@ -618,6 +665,11 @@ class GitDagLineEdit(completion.GitLogLineEdit):
         author_filter = '--author=' + email
         self.insert(author_filter)
 
+    def _filter_to_line_range(self):
+        """Filter to commits by line range expressions"""
+        range_filter = '-L:funcname:filename'
+        self.insert(range_filter)
+
     def _pickaxe_search(self):
         """Pickaxe search for changes containing text"""
         self.insert('-G"search"')
@@ -653,6 +705,7 @@ class CommitTreeWidget(standard.TreeWidget, ViewerMixin):
 
     commits_selected = Signal(object)
     diff_commits = Signal(object, object)
+    search_line_range_in_oid = Signal(object)
     zoom_to_fit = Signal()
 
     def __init__(self, context, parent):
@@ -727,13 +780,13 @@ class CommitTreeWidget(standard.TreeWidget, ViewerMixin):
         """Select the item below the current item"""
         self.goto(self.itemBelow)
 
-    def goto(self, finder):
+    def goto(self, finder_fn):
         """Move the selection using a finder strategy"""
         items = self.selected_items()
         item = items[0] if items else None
         if item is None:
             return
-        found = finder(item)
+        found = finder_fn(item)
         if found:
             self.select([found.commit.oid])
 
@@ -869,7 +922,7 @@ class GitDAG(standard.MainWindow):
         )
 
         self.treewidget = CommitTreeWidget(context, self)
-        self.diffwidget = diff.DiffWidget(context, self, is_commit=True)
+        self.diffwidget = diff.CommitDiffWidget(context, self, is_commit=True)
         self.filewidget = filelist.FileWidget(context, self)
         self.graphview = GraphView(context, self)
 
@@ -997,9 +1050,14 @@ class GitDAG(standard.MainWindow):
 
         self.treewidget.zoom_to_fit.connect(self.graphview.zoom_to_fit)
         self.treewidget.diff_commits.connect(self.diff_commits)
+        self.treewidget.search_line_range_in_oid.connect(self.search_line_range_in_oid)
         self.graphview.diff_commits.connect(self.diff_commits)
+        self.graphview.search_line_range_in_oid.connect(self.search_line_range_in_oid)
         self.filewidget.grab_file.connect(self.grab_file)
         self.filewidget.grab_file_from_parent.connect(self.grab_file_from_parent)
+        self.filewidget.select_line_range_for_file.connect(
+            self.search_line_range_for_file
+        )
         self.maxresults.editingFinished.connect(self.display)
         self.revtext.textChanged.connect(self.text_changed)
         self.revtext.activated.connect(self.display)
@@ -1204,11 +1262,39 @@ class GitDAG(standard.MainWindow):
         self.graphview.set_initial_view()
 
     def diff_commits(self, left, right):
+        """React to diff_commits signals by displaying a difftool interface"""
         paths = self.params.paths()
         if paths:
             difftool.difftool_launch(self.context, left=left, right=right, paths=paths)
         else:
-            difftool.diff_commits(self.context, self, left, right)
+            difftool.diff_commits(self.context, self, left, right, detect_renames=True)
+
+    def search_line_range_in_oid(self, oid):
+        """Open a dialog for generating "git log -L" line range expressions"""
+        all_paths = self.filewidget.selected_paths()
+        if all_paths:
+            paths = all_paths[0]
+        else:
+            paths = None
+        widget = finder.new_finder(
+            self.context,
+            paths=paths,
+            ref=oid,
+            title=N_('Trace Evolution of Line Range'),
+            ok_text=N_('Select Line Range'),
+            parent=self,
+        )
+        widget.search()
+        result = widget.exec_()
+        if result != QtWidgets.QDialog.Accepted:
+            return
+        start, span = widget.selected_line_range()
+        filename = widget.filename
+        if not filename:
+            return
+        range_expression = f'-L{start},+{span}:{filename}'
+        self.revtext.insert(range_expression)
+        self.display()
 
     def histories_selected(self, histories):
         argv = [self.model.currentbranch, '--']
@@ -1237,6 +1323,13 @@ class GitDAG(standard.MainWindow):
         model = browse.BrowseModel(oid, filename=filename)
         browse.save_path(self.context, filename, model)
 
+    def search_line_range_for_file(self, filename):
+        """Generate a line range expression for the specified filename"""
+        oid = self.treewidget.selected_oid()
+        if not oid or not filename:
+            return
+        self.search_line_range_in_oid(oid)
+
     # Qt overrides
     def closeEvent(self, event):
         """Ensure the revtext popup is closed"""
@@ -1260,10 +1353,11 @@ class ReaderThread(QtCore.QThread):
 
     def __init__(self, context, params, parent):
         QtCore.QThread.__init__(self, parent)
-        self.setTerminationEnabled(True)
         self.context = context
         self.params = params
         self._stop = False
+        self._mutex = QtCore.QMutex()
+        self._condition = QtCore.QWaitCondition()
 
     def run(self):
         context = self.context
@@ -1272,8 +1366,14 @@ class ReaderThread(QtCore.QThread):
         self.begin.emit()
         commits = []
         for commit in repo.get():
+            stopped = False
+            self._mutex.lock()
             if self._stop:
+                self._condition.wait(self._mutex)
                 repo.reset()
+                stopped = True
+            self._mutex.unlock()
+            if stopped:
                 return
             commits.append(commit)
             if len(commits) >= 512:
@@ -1297,7 +1397,7 @@ class ReaderThread(QtCore.QThread):
 
     def stop(self):
         self._stop = True
-        self.terminate()
+        self.wait()
 
 
 class Cache:
@@ -1705,6 +1805,7 @@ class Label(QtWidgets.QGraphicsItem):
 class GraphView(QtWidgets.QGraphicsView, ViewerMixin):
     commits_selected = Signal(object)
     diff_commits = Signal(object, object)
+    search_line_range_in_oid = Signal(object)
 
     x_adjust = int(Commit.commit_radius * 4 / 3)
     y_adjust = int(Commit.commit_radius * 4 / 3)
