@@ -184,6 +184,9 @@ scissors
         tooltip = N_('Use gravatar.com to lookup icons for author emails')
         self.enable_gravatar = qtutils.checkbox(checked=True, tooltip=tooltip)
 
+        tooltip = N_('Display desktop notifications using popup dialogs')
+        self.enable_popups = qtutils.checkbox(checked=False, tooltip=tooltip)
+
         tooltip = N_('Enable path autocompletion in tools')
         self.autocomplete_paths = qtutils.checkbox(checked=True, tooltip=tooltip)
 
@@ -210,6 +213,9 @@ scissors
         self.add_row(N_('Show Full Paths in the Window Title'), self.show_path)
         self.add_row(N_('Show Diffstat After Merge'), self.merge_diffstat)
         self.add_row(N_('Display Untracked Files'), self.display_untracked)
+        self.add_row(
+            N_('Display desktop notifications using popup dialogs'), self.enable_popups
+        )
         self.add_row(N_('Enable Gravatar Icons'), self.enable_gravatar)
         self.add_row(N_('Autocomplete Paths'), self.autocomplete_paths)
         self.add_row(N_('Update Index on Startup'), self.update_index)
@@ -238,6 +244,7 @@ scissors
                 Defaults.display_untracked,
             ),
             prefs.ENABLE_GRAVATAR: (self.enable_gravatar, Defaults.enable_gravatar),
+            prefs.ENABLE_POPUPS: (self.enable_popups, Defaults.enable_popups),
             prefs.HTTP_PROXY: (self.http_proxy, Defaults.http_proxy),
             prefs.INOTIFY: (self.inotify, Defaults.inotify),
             prefs.LOGDATE: (self.logdate, Defaults.logdate),
@@ -262,15 +269,14 @@ scissors
 class SettingsFormWidget(FormWidget):
     def __init__(self, context, model, parent):
         FormWidget.__init__(self, context, model, parent)
-
-        self.fixed_font = QtWidgets.QFontComboBox()
-        self.font_size = standard.SpinBox(value=12, mini=6, maxi=192)
         self.maxrecent = standard.SpinBox(maxi=99)
         self.tabwidth = standard.SpinBox(maxi=42)
         self.textwidth = standard.SpinBox(maxi=150)
 
         self.editor = QtWidgets.QLineEdit()
         self.editor.setToolTip(N_('The main GUI editor that must block until it exits'))
+        tooltip = N_('Use "aspell" as the spelling dictionary source')
+        self.aspell_enabled = qtutils.checkbox(tooltip=tooltip)
         self.background_editor = QtWidgets.QLineEdit()
         self.background_editor.setToolTip(
             N_('A non-blocking GUI editor that is launched in the background')
@@ -301,8 +307,6 @@ class SettingsFormWidget(FormWidget):
         tooltip = N_('Emit notifications when commits are pushed.')
         self.notifyonpush = qtutils.checkbox(checked=False, tooltip=tooltip)
 
-        self.add_row(N_('Fixed-Width Font'), self.fixed_font)
-        self.add_row(N_('Font Size'), self.font_size)
         self.add_row(N_('Text Width'), self.textwidth)
         self.add_row(N_('Tab Width'), self.tabwidth)
         self.add_row(N_('Editor'), self.editor)
@@ -325,10 +329,12 @@ class SettingsFormWidget(FormWidget):
         self.add_row(N_('Refresh on Focus'), self.refresh_on_focus)
         self.add_row(N_('Resize File Browser columns'), self.resize_browser_columns)
         self.add_row(N_('Check Spelling'), self.check_spelling)
+        self.add_row(N_('Enable "aspell" Spelling Dictionaries'), self.aspell_enabled)
         self.add_row(N_('Ctrl + MouseWheel to Zoom'), self.mouse_zoom)
         self.add_row(N_('Notify on Push'), self.notifyonpush)
 
         self.set_config({
+            prefs.ASPELL_ENABLED: (self.aspell_enabled, Defaults.aspell_enabled),
             prefs.SAVEWINDOWSETTINGS: (
                 self.save_window_settings,
                 Defaults.save_window_settings,
@@ -371,34 +377,21 @@ class SettingsFormWidget(FormWidget):
             prefs.NOTIFY_ON_PUSH: (self.notifyonpush, Defaults.notifyonpush),
         })
 
-        self.fixed_font.currentFontChanged.connect(self.current_font_changed)
-        self.font_size.valueChanged.connect(self.font_size_changed)
-
-    def update_from_config(self):
-        """Update widgets to the current config values"""
-        FormWidget.update_from_config(self)
-        context = self.context
-
-        with qtutils.BlockSignals(self.fixed_font):
-            font = qtutils.diff_font(context)
-            self.fixed_font.setCurrentFont(font)
-
-        with qtutils.BlockSignals(self.font_size):
-            font_size = font.pointSize()
-            self.font_size.setValue(font_size)
-
-    def font_size_changed(self, size):
-        font = self.fixed_font.currentFont()
-        font.setPointSize(size)
-        cmds.do(prefs.SetConfig, self.model, 'global', prefs.FONTDIFF, font.toString())
-
-    def current_font_changed(self, font):
-        cmds.do(prefs.SetConfig, self.model, 'global', prefs.FONTDIFF, font.toString())
-
 
 class AppearanceFormWidget(FormWidget):
     def __init__(self, context, model, parent):
         FormWidget.__init__(self, context, model, parent)
+        # Fonts
+        font = self.font()
+        font_size = context.cfg.get(prefs.FONTSIZE, font.pointSize())
+        self.default_font_size = font_size
+        self.fixed_font = QtWidgets.QFontComboBox()
+        self.fixed_font_size = standard.SpinBox(value=12, mini=6, maxi=192)
+        self.fixed_font_size.setToolTip(
+            N_('The font size for the fixed-width diff font')
+        )
+        self.font_size = standard.SpinBox(value=font_size, mini=6, maxi=192)
+        self.font_size.setToolTip(N_('The font size for the main UI elements'))
         # Theme selectors
         self.themes = themes.get_all_themes()
         self.theme = qtutils.combo_mapped(themes.options(themes=self.themes))
@@ -414,6 +407,9 @@ class AppearanceFormWidget(FormWidget):
         self.status_indent = qtutils.checkbox()
         self.block_cursor = qtutils.checkbox(checked=True)
 
+        self.add_row(N_('Fixed-Width Font'), self.fixed_font)
+        self.add_row(N_('Font Size'), self.fixed_font_size)
+        self.add_row(N_('Font Size (UI)'), self.font_size)
         self.add_row(N_('GUI theme'), self.theme)
         self.add_row(N_('Icon theme'), self.icon_theme)
         self.add_row(N_('High DPI'), self.high_dpi)
@@ -424,6 +420,10 @@ class AppearanceFormWidget(FormWidget):
 
         self.set_config({
             prefs.BOLD_HEADERS: (self.bold_headers, Defaults.bold_headers),
+            prefs.FONTSIZE: (
+                self.font_size,
+                self.default_font_size,
+            ),
             prefs.HIDPI: (self.high_dpi, Defaults.hidpi),
             prefs.STATUS_SHOW_TOTALS: (
                 self.status_show_totals,
@@ -435,6 +435,9 @@ class AppearanceFormWidget(FormWidget):
             prefs.BLOCK_CURSOR: (self.block_cursor, Defaults.block_cursor),
         })
 
+        self.fixed_font.currentFontChanged.connect(self.current_font_changed)
+        self.fixed_font_size.valueChanged.connect(self.diff_font_size_changed)
+        self.font_size.valueChanged.connect(self.font_size_changed)
         self.theme.currentIndexChanged.connect(self._theme_changed)
 
     def _theme_changed(self, theme_idx):
@@ -455,6 +458,32 @@ class AppearanceFormWidget(FormWidget):
             if icon_theme in ('default', 'dark'):
                 self.icon_theme.set_value('light')
 
+    def update_from_config(self):
+        """Update widgets to the current config values"""
+        FormWidget.update_from_config(self)
+        context = self.context
+
+        with qtutils.BlockSignals(self.fixed_font):
+            font = qtutils.diff_font(context)
+            self.fixed_font.setCurrentFont(font)
+
+        with qtutils.BlockSignals(self.fixed_font_size):
+            font_size = font.pointSize()
+            self.fixed_font_size.setValue(font_size)
+
+    def diff_font_size_changed(self, size):
+        """The diff font size was changed"""
+        font = self.fixed_font.currentFont()
+        font.setPointSize(size)
+        cmds.do(prefs.SetConfig, self.model, 'global', prefs.FONTDIFF, font.toString())
+
+    def font_size_changed(self, size):
+        """The UI font size was changed"""
+        cmds.do(prefs.SetConfig, self.model, 'global', prefs.FONTSIZE, size)
+
+    def current_font_changed(self, font):
+        cmds.do(prefs.SetConfig, self.model, 'global', prefs.FONTDIFF, font.toString())
+
 
 class AppearanceWidget(QtWidgets.QWidget):
     def __init__(self, form, parent):
@@ -515,7 +544,7 @@ class PreferencesView(standard.Dialog):
         )
         # If the user already has the user.email and user.name configured then default
         # to editing the current repo's config instead of the user-wide settings.
-        if self.context.cfg.get('user.name') and self.context.cfg.get('user.email'):
+        if context.cfg.get(prefs.USER_NAME) and context.cfg.get(prefs.USER_EMAIL):
             index = 0
         else:
             index = 1
