@@ -3,11 +3,6 @@ import fnmatch
 import time
 import os
 
-try:
-    import notifypy
-except (ImportError, ModuleNotFoundError):
-    notifypy = None
-
 from qtpy import QtGui
 from qtpy import QtWidgets
 from qtpy.QtCore import Qt
@@ -24,7 +19,6 @@ from .. import display
 from .. import git
 from .. import gitcmds
 from .. import icons
-from .. import resources
 from .. import qtutils
 from .. import utils
 from . import defs
@@ -99,17 +93,6 @@ def strip_remotes(remote_branches):
     return [branch for branch in branches if branch != 'HEAD']
 
 
-def get_default_remote(context):
-    """Get the name of the default remote to use for pushing.
-
-    This will be the remote the branch is set to track, if it is set. If it
-    is not, remote.pushDefault will be used (or origin if not set)
-
-    """
-    upstream_remote = gitcmds.upstream_remote(context)
-    return upstream_remote or context.cfg.get('remote.pushDefault', default='origin')
-
-
 class ActionTask(qtutils.Task):
     """Run actions asynchronously"""
 
@@ -125,7 +108,7 @@ class ActionTask(qtutils.Task):
 
 
 def _emit_push_notification(
-    context, selected_remotes, pushed_remotes, unpushed_remotes
+    context, allow_popups, selected_remotes, pushed_remotes, unpushed_remotes
 ):
     """Emit desktop notification when pushing remotes"""
     total = len(selected_remotes)
@@ -138,13 +121,7 @@ def _emit_push_notification(
 
     pushed_message = N_('Pushed: %s') % ', '.join(pushed_remotes)
     unpushed_message = N_('Not pushed: %s') % ', '.join(unpushed_remotes)
-    success_icon = resources.icon_path('git-cola-ok.svg')
-    error_icon = resources.icon_path('git-cola-error.svg')
-
-    if unpushed_remotes:
-        icon = error_icon
-    else:
-        icon = success_icon
+    error = bool(unpushed_remotes)
 
     if pushed_remotes and unpushed_remotes:
         message = unpushed_message + '\t\t' + pushed_message
@@ -153,7 +130,9 @@ def _emit_push_notification(
     else:
         message = unpushed_message
 
-    display.notify(context.app_name, title, message, icon)
+    display.push_notification(
+        context, title, message, error=error, allow_popups=allow_popups
+    )
 
 
 class RemoteActionDialog(standard.Dialog):
@@ -377,9 +356,8 @@ class RemoteActionDialog(standard.Dialog):
         self.main_layout.setStretchFactor(self.top_layout, 2)
         self.setLayout(self.main_layout)
 
-        default_remote = get_default_remote(context)
-
         remotes = model.remotes
+        default_remote = gitcmds.get_default_remote(context)
         if default_remote in remotes:
             idx = remotes.index(default_remote)
             if self.select_remote(idx):
@@ -734,9 +712,17 @@ class RemoteActionDialog(standard.Dialog):
 
             all_results = combine(result, all_results)
 
+        # Popups interfere with the remote messages dialog.
+        close_on_completion = get(self.close_on_completion_checkbox)
+        remote_messages = get(self.remote_messages_checkbox)
+        allow_popups = not close_on_completion and not remote_messages
         if prefs.notify_on_push(self.context):
             _emit_push_notification(
-                self.context, selected_remotes, pushed_remotes, unpushed_remotes
+                self.context,
+                allow_popups,
+                selected_remotes,
+                pushed_remotes,
+                unpushed_remotes,
             )
 
         return all_results
@@ -764,8 +750,11 @@ class RemoteActionDialog(standard.Dialog):
         remote_branch = self.remote_branch.text()
         local_branch = self.local_branch.text()
 
-        if action == PUSH and not remote_branch:
-            branch = local_branch
+        if action == PUSH:
+            if remote_branch:
+                branch = remote_branch
+            else:
+                branch = local_branch
             candidate = f'{remote}/{branch}'
             prompt = get(self.prompt_checkbox)
 
@@ -948,6 +937,7 @@ class Push(RemoteActionDialog):
     def export_state(self):
         """Export persistent settings"""
         state = RemoteActionDialog.export_state(self)
+        state['force'] = get(self.force_checkbox)
         state['prompt'] = get(self.prompt_checkbox)
         state['tags'] = get(self.tags_checkbox)
         return state
@@ -955,6 +945,9 @@ class Push(RemoteActionDialog):
     def apply_state(self, state):
         """Apply persistent settings"""
         result = RemoteActionDialog.apply_state(self, state)
+        # Restore the "force" checkbox
+        force = bool(state.get('force', False))
+        self.force_checkbox.setChecked(force)
         # Restore the "prompt on creation" checkbox
         prompt = bool(state.get('prompt', True))
         self.prompt_checkbox.setChecked(prompt)
