@@ -135,7 +135,14 @@ class WidgetMixin:
             width = defs.dialog_w
         if not height:
             height = defs.dialog_h
-        self.init_state(settings, self.resize_to_parent, parent, width, height)
+        self.init_state(
+            settings,
+            self.resize_to_parent,
+            parent,
+            width,
+            height,
+            use_parent_height=True,
+        )
 
     def init_state(self, settings, callback, *args, **kwargs):
         """Restore saved settings or set the initial location"""
@@ -143,9 +150,11 @@ class WidgetMixin:
             callback(*args, **kwargs)
             self.center()
 
-    def resize_to_parent(self, parent, w, h):
+    def resize_to_parent(self, parent, w, h, use_parent_height=True):
         """Set the initial size of the widget"""
-        width, height = qtutils.default_size(parent, w, h)
+        width, height = qtutils.default_size(
+            parent, w, h, use_parent_height=use_parent_height
+        )
         self.resize(width, height)
 
 
@@ -164,6 +173,14 @@ class MainWindowMixin(WidgetMixin):
         self.default_state = self.saveState(self.widget_version)
         super().init_state(settings, callback, *args, **kwargs)
 
+    def layout_state(self):
+        """Return the Qt layout state"""
+        return self.saveState(self.widget_version)
+
+    def apply_layout(self, value):
+        """Apply binary Qt layout state"""
+        self.restoreState(value, self.widget_version)
+
     def export_state(self):
         """Exports data for save/restore"""
         state = WidgetMixin.export_state(self)
@@ -802,21 +819,39 @@ class ProgressTickThread(QtCore.QThread):
 
 class SpinBox(QtWidgets.QSpinBox):
     def __init__(
-        self, parent=None, value=None, mini=1, maxi=99999, step=0, prefix='', suffix=''
+        self,
+        parent=None,
+        value=None,
+        mini=1,
+        maxi=99999,
+        step=0,
+        prefix='',
+        suffix='',
+        tooltip='',
+        wrap=False,
     ):
         QtWidgets.QSpinBox.__init__(self, parent)
+        self.setAlignment(Qt.AlignRight)
+        self.setButtonSymbols(QtWidgets.QAbstractSpinBox.PlusMinus)
         self.setPrefix(prefix)
         self.setSuffix(suffix)
         self.setWrapping(True)
         self.setMinimum(mini)
         self.setMaximum(maxi)
+        self.setWrapping(wrap)
         if step:
             self.setSingleStep(step)
         if value is not None:
-            self.setValue(value)
+            self.set_value(value)
         text_width = qtutils.text_width(self.font(), 'MMMMMM')
         width = max(self.minimumWidth(), text_width)
         self.setMinimumWidth(width)
+        if tooltip:
+            self.setToolTip(tooltip)
+
+    def set_value(self, value):
+        """Set the spinbox value directly"""
+        self.setValue(value)
 
 
 class DirectoryPathLineEdit(QtWidgets.QWidget):
@@ -1195,16 +1230,17 @@ def save_as(filename, title):
     return qtutils.save_as(filename, title=title)
 
 
-def async_command(title, cmd, runtask):
-    task = qtutils.SimpleTask(partial(core.run_command, cmd))
-    task.connect(partial(async_command_result, title, cmd))
+def async_task(title, cmd, runtask, func):
+    """Run a function in the background"""
+    task = qtutils.SimpleTask(func)
+    task.connect(partial(_async_task_result, title, cmd))
     runtask.start(task)
 
 
-def async_command_result(title, cmd, result):
+def _async_task_result(title, cmd, result):
+    """Display the result of an asynchronous task"""
     status, out, err = result
-    cmd_string = core.list2cmdline(cmd)
-    Interaction.command(title, cmd_string, status, out, err)
+    Interaction.command(title, cmd, status, out, err)
 
 
 def install():
@@ -1215,4 +1251,4 @@ def install():
     Interaction.information = staticmethod(information)
     Interaction.command_error = staticmethod(command_error)
     Interaction.save_as = staticmethod(save_as)
-    Interaction.async_command = staticmethod(async_command)
+    Interaction.async_task = staticmethod(async_task)
